Module beamlit.models.runtime
=============================

Classes
-------

`Runtime(args: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, command: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, endpoint_name: beamlit.types.Unset | str = <beamlit.types.Unset object>, envs: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, image: beamlit.types.Unset | str = <beamlit.types.Unset object>, metric_port: beamlit.types.Unset | int = <beamlit.types.Unset object>, model: beamlit.types.Unset | str = <beamlit.types.Unset object>, organization: beamlit.types.Unset | str = <beamlit.types.Unset object>, readiness_probe: beamlit.types.Unset | ForwardRef('RuntimeReadinessProbe') = <beamlit.types.Unset object>, resources: beamlit.types.Unset | ForwardRef('RuntimeResources') = <beamlit.types.Unset object>, serving_port: beamlit.types.Unset | int = <beamlit.types.Unset object>, type_: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Set of configurations for a deployment
    
    Attributes:
        args (Union[Unset, list[Any]]): The arguments to pass to the deployment runtime
        command (Union[Unset, list[Any]]): The command to run the deployment
        endpoint_name (Union[Unset, str]): Endpoint Name of the model. In case of hf_private_endpoint, it is the
            endpoint name. In case of hf_public_endpoint, it is not used.
        envs (Union[Unset, list[Any]]): The env variables to set in the deployment. Should be a list of Kubernetes
            EnvVar types
        image (Union[Unset, str]): The Docker image for the deployment
        metric_port (Union[Unset, int]): The port to serve the metrics on
        model (Union[Unset, str]): The slug name of the origin model at HuggingFace.
        organization (Union[Unset, str]): The organization of the model
        readiness_probe (Union[Unset, RuntimeReadinessProbe]): The readiness probe. Should be a Kubernetes Probe type
        resources (Union[Unset, RuntimeResources]): The resources for the deployment. Should be a Kubernetes
            ResourceRequirements type
        serving_port (Union[Unset, int]): The port to serve the model on
        type_ (Union[Unset, str]): The type of origin for the deployment (hf_private_endpoint, hf_public_endpoint)
    
    Method generated by attrs for class Runtime.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `args`
    :

    `command`
    :

    `endpoint_name`
    :

    `envs`
    :

    `image`
    :

    `metric_port`
    :

    `model`
    :

    `organization`
    :

    `readiness_probe`
    :

    `resources`
    :

    `serving_port`
    :

    `type_`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :